<?php
/**
 * @Copyright
 *
 * @package    QCC - Quick Cache Cleaning for Joomla! 3
 * @author     Viktor Vogel <admin@kubik-rubik.de>
 * @version    3.2.0 - 2017-01-02
 * @link       https://joomla-extensions.kubik-rubik.de/qcc-quick-cache-cleaning
 *
 * @license    GNU/GPL
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
defined('_JEXEC') or die('Restricted access');

class ModQuickCacheCleaningHelper
{
	function __construct()
	{
		$quickcachecleaning = JFactory::getApplication()->input->get('quickcachecleaning');

		if(!empty($quickcachecleaning))
		{
			$this->executeCleanCheckin($quickcachecleaning);
		}
	}

	/**
	 * Does the dirty work! :-)
	 *
	 * @param string $quickcachecleaning
	 */
	private function executeCleanCheckin($quickcachecleaning)
	{
		$message = '';

		if($quickcachecleaning == 'clean_cache' OR $quickcachecleaning == 'purge_cache')
		{
			// Get model from cache component to use its functions
			JLoader::import('cache', JPATH_ADMINISTRATOR.'/components/com_cache/models');
			$model = JModelLegacy::getInstance('cache', 'CacheModel');

			if($quickcachecleaning == 'clean_cache')
			{
				$model->clean();
				$message = JText::_('MOD_QUICKCACHECLEANING_CACHE_CLEANED');
			}
			elseif($quickcachecleaning == 'purge_cache')
			{
				$model->purge();
				$message = JText::_('MOD_QUICKCACHECLEANING_CACHE_PURGED');
			}
		}
		elseif($quickcachecleaning == 'check_in')
		{
			// Get model from checkin component to use its functions
			JLoader::import('checkin', JPATH_ADMINISTRATOR.'/components/com_checkin/models');
			$model = JModelLegacy::getInstance('checkin', 'CheckinModel');

			$model->checkin(array_flip(array_filter($model->getItems())));
			$message = JText::_('MOD_QUICKCACHECLEANING_CHECKED_IN');
		}

		$url = preg_replace('@[?|&]quickcachecleaning=(.+)$@', '', JUri::getInstance()->toString());
		JFactory::getApplication()->redirect($url, $message, 'notice');
	}

	/**
	 * Creates the output for the module template.
	 *
	 * @return string
	 */
	public function createOutput($position = '')
	{
		$url_string = JUri::getInstance()->toString();
		$url = $url_string.'?';

		if(strpos($url_string, '?') !== false)
		{
			$url = $url_string.'&';
		}

		$url .= 'quickcachecleaning=';

		$output = '<ul class="position-status nav pull-right">
                    <li class="dropdown">
                        <a href="#" data-toggle="dropdown" class="dropdown-toggle">'.JText::_('MOD_QUICKCACHECLEANING_SELECTION_QUICKCACHECLEANING').' <span class="caret"></span></a>
                        <ul class="dropdown-menu qcc">
                            <li><a href="'.$url.'clean_cache">'.JText::_('MOD_QUICKCACHECLEANING_SELECTION_CACHE_CLEAN').'</a></li>
                            <li class="separator"><span></span></li>
                            <li><a href="'.$url.'purge_cache">'.JText::_('MOD_QUICKCACHECLEANING_SELECTION_CACHE_PURGE').'</a></li>
                            <li class="separator"><span></span></li>
                            <li><a href="'.$url.'check_in">'.JText::_('MOD_QUICKCACHECLEANING_SELECTION_GLOBAL_CHECKIN').'</a></li>
                        </ul>
                    </li>
                </ul>';

		if($position == 'status')
		{
			$document = JFactory::getDocument();
			$css = 'ul.position-status > li > a.dropdown-toggle {padding: 0px 10px;} ul.qcc li a:hover{background-color: #E2E2E2; background-image: none;}';
			$document->addStyleDeclaration($css);
		}

		return $output;
	}
}
